/*
 * MIT License
 *
 * Copyright (c) 2023 Samuel CHEMLA
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in all
 * copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */

package com.phpbg.easysync

import android.app.Application
import android.content.Context
import android.os.StrictMode
import java.lang.System.currentTimeMillis
import kotlin.math.floor
import kotlin.math.max

const val TRIAL_DURATION_DAYS = 30

class MyApp : Application() {
    init {
        if (BuildConfig.DEBUG)
            StrictMode.enableDefaults()
    }

    companion object {
        fun isTrial(): Boolean {
            @Suppress("KotlinConstantConditions")
            return (BuildConfig.FLAVOR == "freeVersion")
        }

        fun getTrialRemainingDays(context: Context): Int {
            val installed = context
                .packageManager
                .getPackageInfo(context.packageName, 0).firstInstallTime
            val now = currentTimeMillis()
            return max(0, TRIAL_DURATION_DAYS- floor((now-installed)/(24*3600*1000).toFloat()).toInt())
        }

        fun isTrialExpired(context: Context): Boolean {
            return isTrial() && getTrialRemainingDays(context) == 0
        }
    }
}